import base64

from django import forms
from django.core.files.base import ContentFile
from django.utils.safestring import mark_safe


class FileWidget(forms.widgets.ClearableFileInput):
    def render(self, name, value, attrs=None):
        attrs["onchange"] = name + "_previewFile()"
        attrs["id"] = "id_" + name + "_tmp"
        file_html = super(FileWidget, self).render(name + "_tmp", value, attrs=attrs)
        html = """
        <script type="text/javascript">
            function """ + name + """_previewFile() {
              var """ + name + """file_input = document.getElementById('id_""" + name + """');
              var file    = document.getElementById('id_""" + name + """_tmp').files[0];
              var reader  = new FileReader();
              reader.addEventListener("load", function () {
                var value = file.name + ":::" +reader.result;
                console.log(value);
                """ + name + """file_input.value = value
              }, false);

              if (file) {
                reader.readAsDataURL(file);
              }
            }
        </script>
        <input type="hidden" value="" name="id_""" + name + """" id="id_""" + name + """" /> """ + file_html + """
        """
        return mark_safe(html)

    def value_from_datadict(self, data, files, name):
        file_data = data["id_" + name]

        """
        file_data: <file_name>:::data:<file content type>;base64,<base64 encoded file data>
        Example : PG Deletion.txt:::data:text/plain;base64,UEcgRGVsZXRpb2tpIjsKCg==
        """

        _data_list = file_data.split(":::")

        if len(_data_list) == 1:
            return None

        file_name = _data_list[0]
        _data_list = _data_list[1].split(";base64,")

        file_extension = _data_list[0].split("data:")[1]
        file_content = _data_list[1]

        return ContentFile(base64.b64decode(file_content), name=file_name)



from django import forms
from django.conf import settings
from django.template import Template, Context
from django.utils.safestring import mark_safe


class URLWidget(forms.widgets.URLInput):
    upload_to = ''

    def __init__(self, *args, **kwargs):
        self.upload_to = kwargs.pop('upload_to', self.upload_to)
        super(URLWidget, self).__init__(*args, **kwargs)

    def render(self, name, value, attrs=None):
        html_template = """
<script src="https://sdk.amazonaws.com/js/aws-sdk-2.1.24.min.js"></script>
<script type="text/javascript">
function {{field_name}}_previewFile() {

    AWS.config.update({
        accessKeyId : '{{AWS_ACCESS_KEY_ID}}',
        secretAccessKey : '{{AWS_SECRET_ACCESS_KEY}}'
    });
    AWS.config.region = '{{AWS_DEFAULT_REGION}}';
    AWS.config.sslEnabled = true;
    AWS.config.logger = true;

    var bucket = new AWS.S3();

    var {{field_name}}file_input = document.getElementById('id_{{field_name}}');
    var {{field_name}}file_url = document.getElementById('id_{{field_name}}_url');
    var {{field_name}}file_loading = document.getElementById('id_{{field_name}}_loading');
    var file    = document.getElementById('id_{{field_name}}_tmp').files[0];
    var reader  = new FileReader();
    reader.addEventListener("load", function () {
        var params = {
            Bucket: '{{AWS_STORAGE_BUCKET_NAME}}',
            Key: '{{prefix}}' + file.name,
            ContentType: file.type,
            Body: file,
            Prefix: '{{prefix}}',
            ACL: 'public-read'
        };
        bucket.upload(params, function (err, data) {
            // results.innerHTML = err ? 'ERROR!' : 'UPLOADED.';
            if (err) {
                alert('Failed to Upload file to s3 ' + err);
            }
            else{
                var s3_key_url = "{{ prefix_url }}" + encodeURI(file.name);
                {{field_name}}file_url.href = s3_key_url;
                {{field_name}}file_url.innerHTML = s3_key_url;
                {{field_name}}file_url.style = 'display:block';
                {{field_name}}file_loading.style = 'display:none';
                {{field_name}}file_input.value = s3_key_url;
            }
        }).on('httpUploadProgress',function(progress) {
          // Log Progress Information
          {{field_name}}file_loading.style = 'display:block';
          var msg = 'Please Wait, Uploading  ' + file.name + ' ('
          {{field_name}}file_loading.innerHTML = msg + Math.round(progress.loaded / progress.total * 100) +'% done)';
        });
    }, false);

    if (file) {
        reader.readAsDataURL(file);
    }
}
</script>
<input type="file" id="id_{{field_name}}_tmp"
onchange="{{field_name}}_previewFile()"/>
<a href="{{field_value}}" id="id_{{field_name}}_url" target="_blank"
style="display:{% if field_value %}block{% else %}none{% endif%}" >{{field_value}}</a><br>
<p id="id_{{field_name}}_loading" style="display:none" ></p>
{{parent_html}}
"""
        attrs['type'] = 'hidden'
        parent_html = super(URLWidget, self).render(name, value, attrs=attrs)
        template = Template(html_template)
        s3_host = 's3-ap-southeast-1.amazonaws.com'
        default_region = getattr(settings, 'AWS_S3_HOST', s3_host).split(".amazonaws.com")[0].split("s3-")[1]
        prefix = settings.MEDIAFILES_LOCATION + "/" + self.upload_to
        context = Context({
            'field_name': name,
            "field_value": value,
            'parent_html': parent_html,
            'prefix': prefix,
            "prefix_url": settings.MEDIA_URL + self.upload_to,
            'AWS_ACCESS_KEY_ID': settings.AWS_ACCESS_KEY_ID,
            'AWS_SECRET_ACCESS_KEY': settings.AWS_SECRET_ACCESS_KEY,
            'AWS_DEFAULT_REGION': default_region,
            'AWS_STORAGE_BUCKET_NAME': settings.AWS_STORAGE_BUCKET_NAME
        })
        html = template.render(context)

        return mark_safe(html)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = '0.1.5'

if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

history = open('HISTORY.rst').read().replace('.. :changelog:', '')

with open(os.path.join(os.path.dirname(__file__), 'requirements.txt')) as f:
    required = f.read().splitlines()

setup(
    name='zappa-file-widget',
    version=version,
    description="""Django Admin File Wiget for Zappa based admin panels""",
    long_description="",
    author='Aneesh Kumar',
    author_email='anush0247@gmail.com',
    url='https://github.com/anush0247/zappa-file-widget',
    packages=[
        'zappa_file_widget',
    ],
    include_package_data=True,
    install_requires=required,
    license="MIT",
    zip_safe=False,
    keywords='zappa-file-widget',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Framework :: Django :: 1.10',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
